@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.contrib import admin
-from bookmark.models import Bookmark, Category, Tag, BookmarkTag
+from shiori.bookmark.models import Bookmark, Category, Tag, BookmarkTag
 
 
 admin.site.register(Bookmark)
